@@ -19,14 +19,14 @@ setMethod("ContaminationSize", signature(e1 = "AbscontDistribution",
 setMethod("ContaminationSize", signature(e1 = "DiscreteDistribution", 
                                          e2 = "DiscreteDistribution"),
     function(e1, e2){
-        owarn <- getOption("warn"); options(warn = -1)
+        o.warn <- getOption("warn"); options(warn = -1)
+        on.exit(options(warn=o.warn))
         x <- union(support(e1), support(e2))
         d10  <- d(e1)(x); d1 <- d10[ d10>0 ]
         d20  <- d(e2)(x); d2 <- d20[ d10>0 ]
         
         res <- min(1- min(d2/d1),1)
 
-        options(warn = owarn)
 
 
         return(list(e1 = e1, e2 = e2, size.of.contamination = res))
